@@ -24,7 +24,7 @@
 #include "xinput.h"
 #include <ctype.h>
 
-static const char rcs_id[] = "$Id: xinput.c,v 1.4 1997/02/07 21:06:02 fred Exp $";
+static const char rcs_id[] = "$Id: xinput.c,v 1.5 1997/06/09 16:06:31 fred Exp $";
 
 typedef int (*prog)(
 #if NeedFunctionPrototypes
@@ -70,6 +70,10 @@ static entry drivers[] =
      "[<device name>...]",
      list
     },
+    {"query-state",
+     "<device name>",
+     query_state
+    },
     {"test",
      "[-proximity] <device name>",
      test
